summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2012-04-13 00:25:47 -0500
committerDarrell Anderson <humanreadable@yahoo.com>2012-04-13 00:25:47 -0500
commitca4b0c6d6aef469eede468b405ea89e119da3626 (patch)
tree6d46d434f32ea33ce92a9416bea7417800fd9479
parent09ef3fbfdda05bff0b0820d4fd6790ac888f789d (diff)
downloadtdegraphics-ca4b0c6d6aef469eede468b405ea89e119da3626.tar.gz
tdegraphics-ca4b0c6d6aef469eede468b405ea89e119da3626.zip
Fix inadvertent "TQ" changes.
-rw-r--r--kdvi/fontMap.cpp2
-rw-r--r--kfile-plugins/jpeg/exif.cpp4
-rw-r--r--kghostview/dscparse/dscparse.cpp2
-rw-r--r--kghostview/dscparse/dscparse.h2
-rw-r--r--kghostview/dscparse/dscparse_adapter.h2
-rw-r--r--kghostview/kgvdocument.cpp4
-rw-r--r--kghostview/kpswidget.cpp2
-rw-r--r--kmrml/kmrml/kcontrol/indexcleaner.cpp8
-rw-r--r--kmrml/kmrml/kcontrol/indexer.cpp8
-rw-r--r--kmrml/kmrml/lib/kmrml_config.cpp10
-rw-r--r--kolourpaint/kpdocument.cpp8
-rw-r--r--kolourpaint/widgets/kpsqueezedtextlabel.cpp26
-rw-r--r--kooka/kookapref.cpp4
-rw-r--r--kooka/resource.h2
-rw-r--r--kpovmodeler/pmpovrayparser.cpp30
-rw-r--r--kpovmodeler/pmquickcolor.h4
-rw-r--r--kpovmodeler/pmquickcoloredit.h4
-rw-r--r--kpovmodeler/pmscanner.cpp14
-rw-r--r--kpovmodeler/pmtokens.h14
-rw-r--r--ksvg/core/KSVGCanvas.cpp2
-rw-r--r--ksvg/data/SVGPathSegImpl.lut.h16
-rw-r--r--ksvg/dom/SVGPathSeg.h8
-rw-r--r--ksvg/impl/SVGPathElementImpl.cc8
-rw-r--r--ksvg/impl/SVGPathSegCurvetoQuadraticImpl.h4
-rw-r--r--ksvg/impl/SVGPathSegCurvetoQuadraticSmoothImpl.h4
-rw-r--r--ksvg/impl/SVGPathSegImpl.cc8
-rw-r--r--ksvg/impl/SVGStylableImpl.cc2
-rw-r--r--ksvg/impl/SVGStylableImpl.h2
-rw-r--r--kviewshell/plugins/djvu/libdjvu/BSEncodeByteStream.cpp16
-rw-r--r--kviewshell/plugins/djvu/libdjvu/JB2EncodeCodec.cpp12
-rw-r--r--kviewshell/plugins/djvu/libdjvu/JB2Image.cpp6
-rw-r--r--kviewshell/plugins/djvu/libdjvu/JB2Image.h8
32 files changed, 123 insertions, 123 deletions
diff --git a/kdvi/fontMap.cpp b/kdvi/fontMap.cpp
index 8cbe4a0e..8ef9b2c7 100644
--- a/kdvi/fontMap.cpp
+++ b/kdvi/fontMap.cpp
@@ -26,7 +26,7 @@ fontMap::fontMap()
// has, like kdvi (and unlike dvips), no built-in fonts.
// Finding ps2pk.map is not easy. In teTeX < 3.0, the kpsewhich
- // program RETQUIRES the option "--format=dvips config". In teTeX =
+ // program REQUIRES the option "--format=dvips config". In teTeX =
// 3.0, the option "--format=map" MUST be used. Since there is no
// way to give both options at the same time, there is seemingly no
// other way than to try both options one after another. We use the
diff --git a/kfile-plugins/jpeg/exif.cpp b/kfile-plugins/jpeg/exif.cpp
index f4803705..60c689bd 100644
--- a/kfile-plugins/jpeg/exif.cpp
+++ b/kfile-plugins/jpeg/exif.cpp
@@ -116,7 +116,7 @@ static int BytesPerFormat[] = {0,1,1,2,4,8,1,1,2,4,8,4,8};
#define TAG_WHITEBALANCE 0x9208
#define TAG_METERING_MODE 0x9207
#define TAG_EXPOSURE_PROGRAM 0x8822
-#define TAG_ISO_ETQUIVALENT 0x8827
+#define TAG_ISO_EQUIVALENT 0x8827
#define TAG_COMPRESSION_LEVEL 0x9102
#define TAG_THUMBNAIL_OFFSET 0x0201
@@ -660,7 +660,7 @@ void ExifData::ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBa
ExifData::ExposureProgram = (int)ConvertAnyFormat(ValuePtr, Format);
break;
- case TAG_ISO_ETQUIVALENT:
+ case TAG_ISO_EQUIVALENT:
ExifData::ISOequivalent = (int)ConvertAnyFormat(ValuePtr, Format);
if ( ExifData::ISOequivalent < 50 ) ExifData::ISOequivalent *= 200;
break;
diff --git a/kghostview/dscparse/dscparse.cpp b/kghostview/dscparse/dscparse.cpp
index b02fb117..7b85395f 100644
--- a/kghostview/dscparse/dscparse.cpp
+++ b/kghostview/dscparse/dscparse.cpp
@@ -2197,7 +2197,7 @@ dsc_scan_comments(CDSC *dsc)
dsc_unknown(dsc);
}
else if (IS_DSC(line, "%%Requirements:")) {
- dsc->id = CDSC_RETQUIREMENTS;
+ dsc->id = CDSC_REQUIREMENTS;
/* ignore */
}
else if (IS_DSC(line, "%%DocumentNeededFonts:")) {
diff --git a/kghostview/dscparse/dscparse.h b/kghostview/dscparse/dscparse.h
index dbac949e..a82a3218 100644
--- a/kghostview/dscparse/dscparse.h
+++ b/kghostview/dscparse/dscparse.h
@@ -106,7 +106,7 @@ typedef enum {
CDSC_DOCUMENTPAPERCOLORS = 215, /* %%DocumentPaperColors: */
CDSC_DOCUMENTPAPERWEIGHTS = 216, /* %%DocumentPaperWeights: */
CDSC_DOCUMENTDATA = 217, /* %%DocumentData: */
- CDSC_RETQUIREMENTS = 218, /* IGNORED %%Requirements: */
+ CDSC_REQUIREMENTS = 218, /* IGNORED %%Requirements: */
CDSC_DOCUMENTNEEDEDFONTS = 219, /* IGNORED %%DocumentNeededFonts: */
CDSC_DOCUMENTSUPPLIEDFONTS = 220, /* IGNORED %%DocumentSuppliedFonts: */
CDSC_HIRESBOUNDINGBOX = 221, /* %%HiResBoundingBox: */
diff --git a/kghostview/dscparse/dscparse_adapter.h b/kghostview/dscparse/dscparse_adapter.h
index 3c9c5734..c5c1cbf9 100644
--- a/kghostview/dscparse/dscparse_adapter.h
+++ b/kghostview/dscparse/dscparse_adapter.h
@@ -193,7 +193,7 @@ public:
DocumentPaperColors = CDSC_DOCUMENTPAPERCOLORS,
DocumentPaperWeights = CDSC_DOCUMENTPAPERWEIGHTS,
DocumentData = CDSC_DOCUMENTDATA,
- Requirements = CDSC_RETQUIREMENTS,
+ Requirements = CDSC_REQUIREMENTS,
DocumentNeededFonts = CDSC_DOCUMENTNEEDEDFONTS,
DocumentSuppliedFonts = CDSC_DOCUMENTSUPPLIEDFONTS,
HiResBoundingBox = CDSC_HIRESBOUNDINGBOX,
diff --git a/kghostview/kgvdocument.cpp b/kghostview/kgvdocument.cpp
index 407566b8..681724a4 100644
--- a/kghostview/kgvdocument.cpp
+++ b/kghostview/kgvdocument.cpp
@@ -774,7 +774,7 @@ void KGVDocument::runPdf2ps( const TQString& pdfName,
KProcess process;
process << _interpreterPath
<< "-dNODISPLAY"
- << "-dTQUIET"
+ << "-dQUIET"
<< TQString( "-sPDFname=%1" ).arg( pdfName )
<< TQString( "-sDSCnamale locale( "kghostview" );
_fallBackPageMedia = pageSizeToString(
@@ -822,7 +822,7 @@ void Pdf2dsc::run( const TQString& pdfName, const TQString& dscName )
<< "-dPARANOIDSAFER"
<< "-dDELAYSAFER"
<< "-dNODISPLAY"
- << "-dTQUIET"
+ << "-dQUIET"
<< TQString( "-sPDFname=%1" ).arg( pdfName )
<< TQString( "-sDSCname=%1" ).arg( dscName )
<< "-c"
diff --git a/kghostview/kpswidget.cpp b/kghostview/kpswidget.cpp
index b5234ac6..eafd3831 100644
--- a/kghostview/kpswidget.cpp
+++ b/kghostview/kpswidget.cpp
@@ -493,7 +493,7 @@ void KPSWidget::readSettings()
if( !Configuration::platformFonts() )
arguments << "-dNOPLATFONTS";
- arguments << "-dNOPAUSE" << "-dTQUIET" << "-dSAFER" << "-dPARANOIDSAFER";
+ arguments << "-dNOPAUSE" << "-dQUIET" << "-dSAFER" << "-dPARANOIDSAFER";
setGhostscriptArguments( arguments );
diff --git a/kmrml/kmrml/kcontrol/indexcleaner.cpp b/kmrml/kmrml/kcontrol/indexcleaner.cpp
index c184c10c..8c75bf9e 100644
--- a/kmrml/kmrml/kcontrol/indexcleaner.cpp
+++ b/kmrml/kmrml/kcontrol/indexcleaner.cpp
@@ -6,9 +6,9 @@
#include <tdeversion.h>
#if TDE_VERSION < 306
- #define TQUOTE( x ) x
+ #define QUOTE( x ) x
#else
- #define TQUOTE( x ) KProcess::quote( x )
+ #define QUOTE( x ) KProcess::quote( x )
#endif
using namespace KMrmlConfig;
@@ -76,9 +76,9 @@ void IndexCleaner::startNext()
int index = cmd.find( "%d" );
if ( index != -1 )
- cmd.replace( index, 2, TQUOTE( dir ) );
+ cmd.replace( index, 2, QUOTE( dir ) );
else // no %d? What else can we do?
- cmd.append( TQString::fromLatin1(" ") + TQUOTE( dir ) );
+ cmd.append( TQString::fromLatin1(" ") + QUOTE( dir ) );
*m_process << cmd;
diff --git a/kmrml/kmrml/kcontrol/indexer.cpp b/kmrml/kmrml/kcontrol/indexer.cpp
index 307cff95..44535c44 100644
--- a/kmrml/kmrml/kcontrol/indexer.cpp
+++ b/kmrml/kmrml/kcontrol/indexer.cpp
@@ -28,9 +28,9 @@
#include <tdeversion.h>
#if TDE_VERSION < 306
- #define TQUOTE( x ) x
+ #define QUOTE( x ) x
#else
- #define TQUOTE( x ) KProcess::quote( x )
+ #define QUOTE( x ) KProcess::quote( x )
#endif
using namespace KMrmlConfig;
@@ -97,10 +97,10 @@ void Indexer::processNext()
// %t with the thumbnail dir
int index = cmd.find( "%d" ); // ### TQFile::encodeName()?
if ( index != -1 )
- cmd.replace( index, 2, TQUOTE( m_currentDir ) );
+ cmd.replace( index, 2, QUOTE( m_currentDir ) );
index = cmd.find( "%t" );
if ( index != -1 )
- cmd.replace( index, 2, TQUOTE(m_currentDir + "_thumbnails") );
+ cmd.replace( index, 2, QUOTE(m_currentDir + "_thumbnails") );
// tqDebug("****** command: %s", cmd.latin1());
#if TDE_VERSION >= 306
diff --git a/kmrml/kmrml/lib/kmrml_config.cpp b/kmrml/kmrml/lib/kmrml_config.cpp
index f8ac6502..1a0f1ac5 100644
--- a/kmrml/kmrml/lib/kmrml_config.cpp
+++ b/kmrml/kmrml/lib/kmrml_config.cpp
@@ -30,9 +30,9 @@
#include <tdeversion.h>
#if TDE_VERSION < 307
- #define TQUOTE( x ) x
+ #define QUOTE( x ) x
#else
- #define TQUOTE( x ) KProcess::quote( x )
+ #define QUOTE( x ) KProcess::quote( x )
#endif
using namespace KMrml;
@@ -183,7 +183,7 @@ TQString Config::addCollectionCommandLine() const
DEFAULT_ADDCOLLECTION_CMD );
int index = cmd.find( "%h" );
if ( index != -1 )
- cmd.replace( index, 2, TQUOTE( mrmldDataDir() ) );
+ cmd.replace( index, 2, QUOTE( mrmldDataDir() ) );
index = cmd.find( "%e" );
if ( index != -1 )
@@ -205,7 +205,7 @@ TQString Config::removeCollectionCommandLine() const
DEFAULT_REMOVECOLLECTION_CMD );
int index = cmd.find( "%h" );
if ( index != -1 )
- cmd.replace( index, 2, TQUOTE( mrmldDataDir() ) );
+ cmd.replace( index, 2, QUOTE( mrmldDataDir() ) );
index = cmd.find( "%e" );
if ( index != -1 )
@@ -241,7 +241,7 @@ TQString Config::mrmldCommandline() const
index = cmd.find( "%d" );
if ( index != -1 )
{
- cmd.replace( index, 2, TQUOTE( mrmldDataDir() ) );
+ cmd.replace( index, 2, QUOTE( mrmldDataDir() ) );
}
tqDebug("***** commandline: %s", cmd.latin1());
diff --git a/kolourpaint/kpdocument.cpp b/kolourpaint/kpdocument.cpp
index d427b598..48eb6641 100644
--- a/kolourpaint/kpdocument.cpp
+++ b/kolourpaint/kpdocument.cpp
@@ -452,7 +452,7 @@ bool kpDocument::lossyPromptContinue (const TQPixmap &pixmap,
kdDebug () << "kpDocument::lossyPromptContinue()" << endl;
#endif
-#define TQUIT_IF_CANCEL(messageBoxCommand) \
+#define QUIT_IF_CANCEL(messageBoxCommand) \
{ \
if (messageBoxCommand != KMessageBox::Continue) \
{ \
@@ -464,7 +464,7 @@ bool kpDocument::lossyPromptContinue (const TQPixmap &pixmap,
if (lossyType & (kpDocumentSaveOptions::MimeTypeMaximumColorDepthLow |
kpDocumentSaveOptions::Quality))
{
- TQUIT_IF_CANCEL (
+ QUIT_IF_CANCEL (
KMessageBox::warningContinueCancel (parent,
i18n ("<qt><p>The <b>%1</b> format may not be able"
" to preserve all of the image's color information.</p>"
@@ -479,7 +479,7 @@ bool kpDocument::lossyPromptContinue (const TQPixmap &pixmap,
}
else if (lossyType & kpDocumentSaveOptions::ColorDepthLow)
{
- TQUIT_IF_CANCEL (
+ QUIT_IF_CANCEL (
KMessageBox::warningContinueCancel (parent,
i18n ("<qt><p>Saving the image at the low color depth of %1-bit"
" may result in the loss of color information."
@@ -492,7 +492,7 @@ bool kpDocument::lossyPromptContinue (const TQPixmap &pixmap,
KStdGuiItem::save (),
TQString::fromLatin1 ("SaveAtLowColorDepthDontAskAgain")));
}
-#undef TQUIT_IF_CANCEL
+#undef QUIT_IF_CANCEL
return true;
}
diff --git a/kolourpaint/widgets/kpsqueezedtextlabel.cpp b/kolourpaint/widgets/kpsqueezedtextlabel.cpp
index dc500b12..0aaea034 100644
--- a/kolourpaint/widgets/kpsqueezedtextlabel.cpp
+++ b/kolourpaint/widgets/kpsqueezedtextlabel.cpp
@@ -25,7 +25,7 @@
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-#define DEBUG_KP_STQUEEZED_TEXT_LABEL 0
+#define DEBUG_KP_SQUEEZED_TEXT_LABEL 0
#include <kpsqueezedtextlabel.h>
@@ -55,7 +55,7 @@ kpSqueezedTextLabel::kpSqueezedTextLabel (const TQString &text, TQWidget *parent
// public virtual
TQSize kpSqueezedTextLabel::minimumSizeHint () const
{
-#if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+#if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "kpSqueezedTextLabel::minimumSizeHint() qLabel prefers"
<< TQLabel::minimumSizeHint () << endl;
#endif
@@ -99,7 +99,7 @@ void kpSqueezedTextLabel::setText (const TQString &text)
// protected virtual [base TQWidget]
void kpSqueezedTextLabel::resizeEvent (TQResizeEvent *e)
{
-#if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+#if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "kpSqueezedTextLabeL::resizeEvent() size=" << e->size ()
<< " oldSize=" << e->oldSize ()
<< endl;
@@ -117,13 +117,13 @@ TQString kpSqueezedTextLabel::ellipsisText () const
// protected
void kpSqueezedTextLabel::squeezeText ()
{
-#if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+#if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "kpSqueezedTextLabeL::squeezeText" << endl;
#endif
TQFontMetrics fontMetrics (font ());
int fullTextWidth = fontMetrics.width (m_fullText);
-#if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+#if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "\tfullText=" << m_fullText
<< " fullTextWidth=" << fullTextWidth
<< " labelWidth=" << width ()
@@ -132,14 +132,14 @@ void kpSqueezedTextLabel::squeezeText ()
if (fullTextWidth <= width ())
{
- #if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+ #if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "\tfullText will fit - display" << endl;
#endif
TQLabel::setText (m_fullText);
}
else
{
- #if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+ #if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "\tfullText won't fit :( - squeeze" << endl;
kdDebug () << "\t\twidth of \"...\"="
<< fontMetrics.width (ellipsisText ())
@@ -148,7 +148,7 @@ void kpSqueezedTextLabel::squeezeText ()
#endif
if (fontMetrics.width (ellipsisText ()) > width ())
{
- #if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+ #if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "\t\t\tcan't even fit \"...\" - forget it" << endl;
#endif
TQLabel::setText (TQString());
@@ -164,7 +164,7 @@ void kpSqueezedTextLabel::squeezeText ()
{
int numLettersToUseMid = (numLettersToUseLo + numLettersToUseHi) / 2;
int squeezedWidth = fontMetrics.width (m_fullText.left (numLettersToUseMid) + ellipsisText ());
- #if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+ #if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "\tbsearch: lo=" << numLettersToUseLo
<< " hi=" << numLettersToUseHi
<< " mid=" << numLettersToUseMid
@@ -175,7 +175,7 @@ void kpSqueezedTextLabel::squeezeText ()
if (squeezedWidth == width ())
{
- #if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+ #if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "\t\tperfect match!" << endl;
#endif
numLettersToUse = numLettersToUseMid;
@@ -183,14 +183,14 @@ void kpSqueezedTextLabel::squeezeText ()
}
else if (squeezedWidth < width ())
{
- #if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+ #if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "\t\tsmall enough - numLettersToUse="
<< numLettersToUse << endl;
#endif
if (numLettersToUseMid > numLettersToUse)
{
numLettersToUse = numLettersToUseMid;
- #if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+ #if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "\t\t\tset numLettersToUse="
<< numLettersToUse
<< endl;
@@ -201,7 +201,7 @@ void kpSqueezedTextLabel::squeezeText ()
}
else
{
- #if DEBUG_KP_STQUEEZED_TEXT_LABEL && 1
+ #if DEBUG_KP_SQUEEZED_TEXT_LABEL && 1
kdDebug () << "\t\ttoo big" << endl;
#endif
numLettersToUseHi = numLettersToUseMid - 1;
diff --git a/kooka/kookapref.cpp b/kooka/kookapref.cpp
index 7444c4fe..6b88fb33 100644
--- a/kooka/kookapref.cpp
+++ b/kooka/kookapref.cpp
@@ -316,7 +316,7 @@ void KookaPreferences::setupStartupPage()
/* Query for network scanner (Checkbox) */
cbNetQuery = new TQCheckBox( i18n("Query network for available scanners"),
- page, "CB_NET_TQUERY" );
+ page, "CB_NET_QUERY" );
TQToolTip::add( cbNetQuery,
i18n( "Check this if you want a network query for available scanners.\nNote that this does not mean a query over the entire network but only the stations configured for SANE!" ));
cbNetQuery->setChecked( ! (konf->readBoolEntry( STARTUP_ONLY_LOCAL, false )) );
@@ -356,7 +356,7 @@ void KookaPreferences::setupSaveFormatPage( )
/* Skip the format asking if a format entry exists */
cbSkipFormatAsk = new TQCheckBox( i18n("Always display image save assistant"),
- page, "CB_IMGASSIST_TQUERY" );
+ page, "CB_IMGASSIST_QUERY" );
cbSkipFormatAsk->setChecked( konf->readBoolEntry( OP_FILE_ASK_FORMAT, true ));
TQToolTip::add( cbSkipFormatAsk, i18n("Check this if you want to see the image save assistant even if there is a default format for the image type." ));
top->addWidget( cbSkipFormatAsk );
diff --git a/kooka/resource.h b/kooka/resource.h
index 687a7ddc..524ca87d 100644
--- a/kooka/resource.h
+++ b/kooka/resource.h
@@ -52,7 +52,7 @@
#define ID_FILE_PRINT 10080
-#define ID_FILE_TQUIT 10100
+#define ID_FILE_QUIT 10100
///////////////////////////////////////////////////////////////////
diff --git a/kpovmodeler/pmpovrayparser.cpp b/kpovmodeler/pmpovrayparser.cpp
index 7f041b3e..c8cdd84f 100644
--- a/kpovmodeler/pmpovrayparser.cpp
+++ b/kpovmodeler/pmpovrayparser.cpp
@@ -289,9 +289,9 @@ bool PMPovrayParser::parseChildObjects( PMCompositeObject* parent,
child = new PMPlane( m_pPart );
error = !parsePlane( ( PMPlane* ) child );
break;
- case TQUADRIC_TOK:
+ case QUADRIC_TOK:
case CUBIC_TOK:
- case TQUARTIC_TOK:
+ case QUARTIC_TOK:
case POLY_TOK:
child = new PMPolynom( m_pPart );
error = !parsePolynom( ( PMPolynom* ) child );
@@ -364,7 +364,7 @@ bool PMPovrayParser::parseChildObjects( PMCompositeObject* parent,
case MARBLE_TOK:
case ONION_TOK:
case PLANAR_TOK:
- case TQUILTED_TOK:
+ case QUILTED_TOK:
case RADIAL_TOK:
case RIPPLES_TOK:
case SLOPE_TOK:
@@ -733,9 +733,9 @@ bool PMPovrayParser::parseChildObjects( PMCompositeObject* parent,
case SMOOTH_TRIANGLE_TOK:
// infinite solid
case PLANE_TOK:
- case TQUADRIC_TOK:
+ case QUADRIC_TOK:
case CUBIC_TOK:
- case TQUARTIC_TOK:
+ case QUARTIC_TOK:
case POLY_TOK:
// csg
case UNION_TOK:
@@ -2331,7 +2331,7 @@ bool PMPovrayParser::parseJuliaFractal( PMJuliaFractal* pNewFractal )
switch( m_token )
{
- case TQUATERNION_TOK:
+ case QUATERNION_TOK:
pNewFractal->setAlgebraType( PMJuliaFractal::Quaternion );
nextToken( );
break;
@@ -2515,8 +2515,8 @@ bool PMPovrayParser::parsePolynom( PMPolynom* pNewPoly )
pNewPoly->setSturm( false );
- if( ( m_token == TQUADRIC_TOK ) || ( m_token == CUBIC_TOK ) ||
- ( m_token == TQUARTIC_TOK ) || ( m_token == POLY_TOK ) )
+ if( ( m_token == QUADRIC_TOK ) || ( m_token == CUBIC_TOK ) ||
+ ( m_token == QUARTIC_TOK ) || ( m_token == POLY_TOK ) )
{
nextToken( );
if( !parseToken( '{' ) )
@@ -2525,7 +2525,7 @@ bool PMPovrayParser::parsePolynom( PMPolynom* pNewPoly )
else
printExpected( "poly", m_pScanner->sValue( ) );
- if( type == TQUADRIC_TOK )
+ if( type == QUADRIC_TOK )
{
c = PMVector( 10 );
pNewPoly->setPolynomOrder( 2 );
@@ -2565,7 +2565,7 @@ bool PMPovrayParser::parsePolynom( PMPolynom* pNewPoly )
{
if( type == CUBIC_TOK )
order = 3;
- else if( type == TQUARTIC_TOK )
+ else if( type == QUARTIC_TOK )
order = 4;
else
{
@@ -2846,7 +2846,7 @@ bool PMPovrayParser::parseLathe( PMLathe* pNewLathe )
nextToken( );
minp = 2;
break;
- case TQUADRATIC_SPLINE_TOK:
+ case QUADRATIC_SPLINE_TOK:
pNewLathe->setSplineType( PMLathe::QuadraticSpline );
nextToken( );
minp = 3;
@@ -2934,7 +2934,7 @@ bool PMPovrayParser::parsePrism( PMPrism* pNewPrism )
nextToken( );
minp = 3;
break;
- case TQUADRATIC_SPLINE_TOK:
+ case QUADRATIC_SPLINE_TOK:
pNewPrism->setSplineType( PMPrism::QuadraticSpline );
nextToken( );
minp = 4;
@@ -3911,7 +3911,7 @@ bool PMPovrayParser::parsePattern( PMPattern* pattern, bool normal )
pattern->setPatternType( PMPattern::PatternPlanar );
type = true;
break;
- case TQUILTED_TOK:
+ case QUILTED_TOK:
nextToken( );
pattern->setPatternType( PMPattern::PatternQuilted );
type = true;
@@ -6436,9 +6436,9 @@ bool PMPovrayParser::parseDeclare( PMDeclare* decl )
child = new PMPlane( m_pPart );
error = !parsePlane( ( PMPlane* ) child );
break;
- case TQUADRIC_TOK:
+ case QUADRIC_TOK:
case CUBIC_TOK:
- case TQUARTIC_TOK:
+ case QUARTIC_TOK:
case POLY_TOK:
child = new PMPolynom( m_pPart );
error = !parsePolynom( ( PMPolynom* ) child );
diff --git a/kpovmodeler/pmquickcolor.h b/kpovmodeler/pmquickcolor.h
index c64d363f..84a3afb5 100644
--- a/kpovmodeler/pmquickcolor.h
+++ b/kpovmodeler/pmquickcolor.h
@@ -19,8 +19,8 @@
**************************************************************************/
-#ifndef PMTQUICKCOLOR_H
-#define PMTQUICKCOLOR_H
+#ifndef PMQUICKCOLOR_H
+#define PMQUICKCOLOR_H
#ifdef HAVE_CONFIG_H
#include <config.h>
diff --git a/kpovmodeler/pmquickcoloredit.h b/kpovmodeler/pmquickcoloredit.h
index 3577916a..2dca5a5f 100644
--- a/kpovmodeler/pmquickcoloredit.h
+++ b/kpovmodeler/pmquickcoloredit.h
@@ -17,8 +17,8 @@
**************************************************************************/
-#ifndef PMTQUICKCOLOREDIT_H
-#define PMTQUICKCOLOREDIT_H
+#ifndef PMQUICKCOLOREDIT_H
+#define PMQUICKCOLOREDIT_H
#ifdef HAVE_CONFIG_H
#include <config.h>
diff --git a/kpovmodeler/pmscanner.cpp b/kpovmodeler/pmscanner.cpp
index d85fa3fb..c90c9728 100644
--- a/kpovmodeler/pmscanner.cpp
+++ b/kpovmodeler/pmscanner.cpp
@@ -304,13 +304,13 @@ PMReservedWordDict::PMReservedWordDict( PMDictMode mode )
insert( "prism", new int( PRISM_TOK ) );
insert( "projected_through", new int( PROJECTED_THROUGH_TOK ) );
insert( "pwr", new int( PWR_TOK ) );
- insert( "quadratic_spline", new int( TQUADRATIC_SPLINE_TOK ) );
- insert( "quadric", new int( TQUADRIC_TOK ) );
- insert( "quartic", new int( TQUARTIC_TOK ) );
- insert( "quaternion", new int( TQUATERNION_TOK ) );
- insert( "quick_color", new int( TQUICK_COLOR_TOK ) );
- insert( "quick_colour", new int( TQUICK_COLOUR_TOK ) );
- insert( "quilted", new int( TQUILTED_TOK ) );
+ insert( "quadratic_spline", new int( QUADRATIC_SPLINE_TOK ) );
+ insert( "quadric", new int( QUADRIC_TOK ) );
+ insert( "quartic", new int( QUARTIC_TOK ) );
+ insert( "quaternion", new int( QUATERNION_TOK ) );
+ insert( "quick_color", new int( QUICK_COLOR_TOK ) );
+ insert( "quick_colour", new int( QUICK_COLOUR_TOK ) );
+ insert( "quilted", new int( QUILTED_TOK ) );
insert( "radial", new int( RADIAL_TOK ) );
insert( "radians", new int( RADIANS_TOK ) );
insert( "radiosity", new int( RADIOSITY_TOK ) );
diff --git a/kpovmodeler/pmtokens.h b/kpovmodeler/pmtokens.h
index 785bb1db..21b4b34b 100644
--- a/kpovmodeler/pmtokens.h
+++ b/kpovmodeler/pmtokens.h
@@ -308,13 +308,13 @@ enum PMToken {
PRISM_TOK,
PROJECTED_THROUGH_TOK,
PWR_TOK,
- TQUADRATIC_SPLINE_TOK,
- TQUADRIC_TOK,
- TQUARTIC_TOK,
- TQUATERNION_TOK,
- TQUICK_COLOR_TOK,
- TQUICK_COLOUR_TOK,
- TQUILTED_TOK,
+ QUADRATIC_SPLINE_TOK,
+ QUADRIC_TOK,
+ QUARTIC_TOK,
+ QUATERNION_TOK,
+ QUICK_COLOR_TOK,
+ QUICK_COLOUR_TOK,
+ QUILTED_TOK,
RADIAL_TOK,
RADIANS_TOK,
RADIOSITY_TOK,
diff --git a/ksvg/core/KSVGCanvas.cpp b/ksvg/core/KSVGCanvas.cpp
index bbd63524..347e00ba 100644
--- a/ksvg/core/KSVGCanvas.cpp
+++ b/ksvg/core/KSVGCanvas.cpp
@@ -341,7 +341,7 @@ T2P::FontVisualParams *KSVGCanvas::fontVisualParams(SVGStylableImpl *style) cons
slant |= FC_SLANT_ROMAN;
else if(fontStyle == ITALIC)
slant |= FC_SLANT_ITALIC;
- else if(fontStyle == OBLITQUE)
+ else if(fontStyle == OBLIQUE)
slant |= FC_SLANT_OBLIQUE;
// Calc font names
diff --git a/ksvg/data/SVGPathSegImpl.lut.h b/ksvg/data/SVGPathSegImpl.lut.h
index 307db965..237e1cb6 100644
--- a/ksvg/data/SVGPathSegImpl.lut.h
+++ b/ksvg/data/SVGPathSegImpl.lut.h
@@ -28,12 +28,12 @@ namespace KSVG {
static const char SVGPathSegImplConstructor__s_hashTableStrings[] = {
"\0"
- "PATHSEG_CURVETO_TQUADRATIC_SMOOTH_ABS\0"
- "PATHSEG_CURVETO_TQUADRATIC_SMOOTH_REL\0"
+ "PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS\0"
+ "PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL\0"
"PATHSEG_CURVETO_CUBIC_SMOOTH_ABS\0"
"PATHSEG_CURVETO_CUBIC_SMOOTH_REL\0"
- "PATHSEG_CURVETO_TQUADRATIC_ABS\0"
- "PATHSEG_CURVETO_TQUADRATIC_REL\0"
+ "PATHSEG_CURVETO_QUADRATIC_ABS\0"
+ "PATHSEG_CURVETO_QUADRATIC_REL\0"
"PATHSEG_LINETO_HORIZONTAL_ABS\0"
"PATHSEG_LINETO_HORIZONTAL_REL\0"
"PATHSEG_LINETO_VERTICAL_ABS\0"
@@ -56,7 +56,7 @@ static const struct HashEntry SVGPathSegImplConstructor__s_hashTableEntries[] =
{ 317, KSVG::PATHSEG_CURVETO_CUBIC_ABS, DontDelete|ReadOnly, 0, -1 },
{ 0, 0, 0, 0, -1 },
{ 0, 0, 0, 0, -1 },
- { 171, KSVG::PATHSEG_CURVETO_TQUADRATIC_REL, DontDelete|ReadOnly, 0, 27 },
+ { 171, KSVG::PATHSEG_CURVETO_QUADRATIC_REL, DontDelete|ReadOnly, 0, 27 },
{ 479, KSVG::PATHSEG_ARC_REL, DontDelete|ReadOnly, 0, -1 },
{ 495, KSVG::PATHSEG_UNKNOWN, DontDelete|ReadOnly, 0, 23 },
{ 369, KSVG::PATHSEG_LINETO_ABS, DontDelete|ReadOnly, 0, -1 },
@@ -73,14 +73,14 @@ static const struct HashEntry SVGPathSegImplConstructor__s_hashTableEntries[] =
{ 75, KSVG::PATHSEG_CURVETO_CUBIC_SMOOTH_ABS, DontDelete|ReadOnly, 0, -1 },
{ 231, KSVG::PATHSEG_LINETO_HORIZONTAL_REL, DontDelete|ReadOnly, 0, -1 },
{ 388, KSVG::PATHSEG_LINETO_REL, DontDelete|ReadOnly, 0, -1 },
- { 38, KSVG::PATHSEG_CURVETO_TQUADRATIC_SMOOTH_REL, DontDelete|ReadOnly, 0, -1 },
+ { 38, KSVG::PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL, DontDelete|ReadOnly, 0, -1 },
{ 407, KSVG::PATHSEG_MOVETO_ABS, DontDelete|ReadOnly, 0, -1 },
{ 445, KSVG::PATHSEG_CLOSEPATH, DontDelete|ReadOnly, 0, 25 },
- { 141, KSVG::PATHSEG_CURVETO_TQUADRATIC_ABS, DontDelete|ReadOnly, 0, 26 },
+ { 141, KSVG::PATHSEG_CURVETO_QUADRATIC_ABS, DontDelete|ReadOnly, 0, 26 },
{ 201, KSVG::PATHSEG_LINETO_HORIZONTAL_ABS, DontDelete|ReadOnly, 0, -1 },
{ 261, KSVG::PATHSEG_LINETO_VERTICAL_ABS, DontDelete|ReadOnly, 0, -1 },
{ 289, KSVG::PATHSEG_LINETO_VERTICAL_REL, DontDelete|ReadOnly, 0, -1 },
- { 1, KSVG::PATHSEG_CURVETO_TQUADRATIC_SMOOTH_ABS, DontDelete|ReadOnly, 0, -1 }
+ { 1, KSVG::PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS, DontDelete|ReadOnly, 0, -1 }
};
const struct HashTable SVGPathSegImplConstructor::s_hashTable = { 2, 29, SVGPathSegImplConstructor__s_hashTableEntries, 23, SVGPathSegImplConstructor__s_hashTableStrings};
diff --git a/ksvg/dom/SVGPathSeg.h b/ksvg/dom/SVGPathSeg.h
index 0120276b..f82e3c80 100644
--- a/ksvg/dom/SVGPathSeg.h
+++ b/ksvg/dom/SVGPathSeg.h
@@ -35,8 +35,8 @@ enum
PATHSEG_LINETO_REL = 5,
PATHSEG_CURVETO_CUBIC_ABS = 6,
PATHSEG_CURVETO_CUBIC_REL = 7,
- PATHSEG_CURVETO_TQUADRATIC_ABS = 8,
- PATHSEG_CURVETO_TQUADRATIC_REL = 9,
+ PATHSEG_CURVETO_QUADRATIC_ABS = 8,
+ PATHSEG_CURVETO_QUADRATIC_REL = 9,
PATHSEG_ARC_ABS = 10,
PATHSEG_ARC_REL = 11,
PATHSEG_LINETO_HORIZONTAL_ABS = 12,
@@ -45,8 +45,8 @@ enum
PATHSEG_LINETO_VERTICAL_REL = 15,
PATHSEG_CURVETO_CUBIC_SMOOTH_ABS = 16,
PATHSEG_CURVETO_CUBIC_SMOOTH_REL = 17,
- PATHSEG_CURVETO_TQUADRATIC_SMOOTH_ABS = 18,
- PATHSEG_CURVETO_TQUADRATIC_SMOOTH_REL = 19
+ PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS = 18,
+ PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL = 19
};
class SVGPathSegImpl;
diff --git a/ksvg/impl/SVGPathElementImpl.cc b/ksvg/impl/SVGPathElementImpl.cc
index 5a0d0057..506ad01a 100644
--- a/ksvg/impl/SVGPathElementImpl.cc
+++ b/ksvg/impl/SVGPathElementImpl.cc
@@ -678,21 +678,21 @@ SVGPathElementImpl::MarkerData::MarkerData(SVGPathSegListImpl *path)
previousCubicY2 = cury + s->y2();
break;
}
- case PATHSEG_CURVETO_TQUADRATIC_ABS:
+ case PATHSEG_CURVETO_QUADRATIC_ABS:
{
SVGPathSegCurvetoQuadraticAbsImpl *s = static_cast<SVGPathSegCurvetoQuadraticAbsImpl *>(segment);
previousQuadraticX1 = s->x1();
previousQuadraticY1 = s->y1();
break;
}
- case PATHSEG_CURVETO_TQUADRATIC_REL:
+ case PATHSEG_CURVETO_QUADRATIC_REL:
{
SVGPathSegCurvetoQuadraticRelImpl *s = static_cast<SVGPathSegCurvetoQuadraticRelImpl *>(segment);
previousQuadraticX1 = curx + s->x1();
previousQuadraticY1 = cury + s->y1();
break;
}
- case PATHSEG_CURVETO_TQUADRATIC_SMOOTH_ABS:
+ case PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS:
{
SVGPathSegCurvetoQuadraticSmoothAbsImpl *s = static_cast<SVGPathSegCurvetoQuadraticSmoothAbsImpl *>(segment);
s->setPreviousX1(previousQuadraticX1);
@@ -701,7 +701,7 @@ SVGPathElementImpl::MarkerData::MarkerData(SVGPathSegListImpl *path)
previousQuadraticY1 = s->y1(cury);
break;
}
- case PATHSEG_CURVETO_TQUADRATIC_SMOOTH_REL:
+ case PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL:
{
SVGPathSegCurvetoQuadraticSmoothRelImpl *s = static_cast<SVGPathSegCurvetoQuadraticSmoothRelImpl *>(segment);
s->setPreviousAbsX1(previousQuadraticX1);
diff --git a/ksvg/impl/SVGPathSegCurvetoQuadraticImpl.h b/ksvg/impl/SVGPathSegCurvetoQuadraticImpl.h
index 1fa0aa17..6772605f 100644
--- a/ksvg/impl/SVGPathSegCurvetoQuadraticImpl.h
+++ b/ksvg/impl/SVGPathSegCurvetoQuadraticImpl.h
@@ -34,7 +34,7 @@ public:
SVGPathSegCurvetoQuadraticAbsImpl();
virtual ~SVGPathSegCurvetoQuadraticAbsImpl();
- virtual unsigned short pathSegType() const { return PATHSEG_CURVETO_TQUADRATIC_ABS; }
+ virtual unsigned short pathSegType() const { return PATHSEG_CURVETO_QUADRATIC_ABS; }
virtual DOM::DOMString pathSegTypeAsLetter() const { return "Q"; }
virtual TQString toString() const { return TQString("Q %1 %2 %3 %4").arg(m_x1).arg(m_y1).arg(m_x).arg(m_y); }
@@ -78,7 +78,7 @@ public:
SVGPathSegCurvetoQuadraticRelImpl();
virtual ~SVGPathSegCurvetoQuadraticRelImpl();
- virtual unsigned short pathSegType() const { return PATHSEG_CURVETO_TQUADRATIC_REL; }
+ virtual unsigned short pathSegType() const { return PATHSEG_CURVETO_QUADRATIC_REL; }
virtual DOM::DOMString pathSegTypeAsLetter() const { return "q"; }
virtual TQString toString() const { return TQString("q %1 %2 %3 %4").arg(m_x1).arg(m_y1).arg(m_x).arg(m_y); }
diff --git a/ksvg/impl/SVGPathSegCurvetoQuadraticSmoothImpl.h b/ksvg/impl/SVGPathSegCurvetoQuadraticSmoothImpl.h
index 1d1bdf39..6c471bd6 100644
--- a/ksvg/impl/SVGPathSegCurvetoQuadraticSmoothImpl.h
+++ b/ksvg/impl/SVGPathSegCurvetoQuadraticSmoothImpl.h
@@ -34,7 +34,7 @@ public:
SVGPathSegCurvetoQuadraticSmoothAbsImpl();
virtual ~SVGPathSegCurvetoQuadraticSmoothAbsImpl();
- virtual unsigned short pathSegType() const { return PATHSEG_CURVETO_TQUADRATIC_SMOOTH_ABS; }
+ virtual unsigned short pathSegType() const { return PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS; }
virtual DOM::DOMString pathSegTypeAsLetter() const { return "T"; }
virtual TQString toString() const { return TQString("T %1 %2").arg(m_x).arg(m_y); }
@@ -78,7 +78,7 @@ public:
SVGPathSegCurvetoQuadraticSmoothRelImpl();
virtual ~SVGPathSegCurvetoQuadraticSmoothRelImpl();
- virtual unsigned short pathSegType() const { return PATHSEG_CURVETO_TQUADRATIC_SMOOTH_REL; }
+ virtual unsigned short pathSegType() const { return PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL; }
virtual DOM::DOMString pathSegTypeAsLetter() const { return "t"; }
virtual TQString toString() const { return TQString("t %1 %2").arg(m_x).arg(m_y); }
diff --git a/ksvg/impl/SVGPathSegImpl.cc b/ksvg/impl/SVGPathSegImpl.cc
index ba2c8ec2..c1f2934d 100644
--- a/ksvg/impl/SVGPathSegImpl.cc
+++ b/ksvg/impl/SVGPathSegImpl.cc
@@ -79,8 +79,8 @@ Value SVGPathSegImpl::getValueProperty(ExecState *, int token) const
PATHSEG_LINETO_REL KSVG::PATHSEG_LINETO_REL DontDelete|ReadOnly
PATHSEG_CURVETO_CUBIC_ABS KSVG::PATHSEG_CURVETO_CUBIC_ABS DontDelete|ReadOnly
PATHSEG_CURVETO_CUBIC_REL KSVG::PATHSEG_CURVETO_CUBIC_REL DontDelete|ReadOnly
- PATHSEG_CURVETO_TQUADRATIC_ABS KSVG::PATHSEG_CURVETO_TQUADRATIC_ABS DontDelete|ReadOnly
- PATHSEG_CURVETO_TQUADRATIC_REL KSVG::PATHSEG_CURVETO_TQUADRATIC_REL DontDelete|ReadOnly
+ PATHSEG_CURVETO_QUADRATIC_ABS KSVG::PATHSEG_CURVETO_QUADRATIC_ABS DontDelete|ReadOnly
+ PATHSEG_CURVETO_QUADRATIC_REL KSVG::PATHSEG_CURVETO_QUADRATIC_REL DontDelete|ReadOnly
PATHSEG_ARC_ABS KSVG::PATHSEG_ARC_ABS DontDelete|ReadOnly
PATHSEG_ARC_REL KSVG::PATHSEG_ARC_REL DontDelete|ReadOnly
PATHSEG_LINETO_HORIZONTAL_ABS KSVG::PATHSEG_LINETO_HORIZONTAL_ABS DontDelete|ReadOnly
@@ -89,8 +89,8 @@ Value SVGPathSegImpl::getValueProperty(ExecState *, int token) const
PATHSEG_LINETO_VERTICAL_REL KSVG::PATHSEG_LINETO_VERTICAL_REL DontDelete|ReadOnly
PATHSEG_CURVETO_CUBIC_SMOOTH_ABS KSVG::PATHSEG_CURVETO_CUBIC_SMOOTH_ABS DontDelete|ReadOnly
PATHSEG_CURVETO_CUBIC_SMOOTH_REL KSVG::PATHSEG_CURVETO_CUBIC_SMOOTH_REL DontDelete|ReadOnly
- PATHSEG_CURVETO_TQUADRATIC_SMOOTH_ABS KSVG::PATHSEG_CURVETO_TQUADRATIC_SMOOTH_ABS DontDelete|ReadOnly
- PATHSEG_CURVETO_TQUADRATIC_SMOOTH_REL KSVG::PATHSEG_CURVETO_TQUADRATIC_SMOOTH_REL DontDelete|ReadOnly
+ PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS KSVG::PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS DontDelete|ReadOnly
+ PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL KSVG::PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL DontDelete|ReadOnly
@end
*/
diff --git a/ksvg/impl/SVGStylableImpl.cc b/ksvg/impl/SVGStylableImpl.cc
index 9471c562..c03c6f19 100644
--- a/ksvg/impl/SVGStylableImpl.cc
+++ b/ksvg/impl/SVGStylableImpl.cc
@@ -974,7 +974,7 @@ void SVGStylableImpl::putValueProperty(ExecState *exec, int token, const Value &
else if(param == "italic")
m_fontStyle = ITALIC;
else if(param == "oblique")
- m_fontStyle = OBLITQUE;
+ m_fontStyle = OBLIQUE;
break;
case TextDecoration:
m_flags |= SVG_STYLE_FLAG_TEXT_DECORATION;
diff --git a/ksvg/impl/SVGStylableImpl.h b/ksvg/impl/SVGStylableImpl.h
index 34ce2f4e..50a37568 100644
--- a/ksvg/impl/SVGStylableImpl.h
+++ b/ksvg/impl/SVGStylableImpl.h
@@ -162,7 +162,7 @@ enum EUnicodeBidi
enum EFontStyle
{
- FSNORMAL, ITALIC, OBLITQUE
+ FSNORMAL, ITALIC, OBLIQUE
};
enum ETextWritingMode
diff --git a/kviewshell/plugins/djvu/libdjvu/BSEncodeByteStream.cpp b/kviewshell/plugins/djvu/libdjvu/BSEncodeByteStream.cpp
index 350d792d..9d5b726d 100644
--- a/kviewshell/plugins/djvu/libdjvu/BSEncodeByteStream.cpp
+++ b/kviewshell/plugins/djvu/libdjvu/BSEncodeByteStream.cpp
@@ -104,7 +104,7 @@ static const int OVERFLOW=32;
// Sorting tresholds
static const int RANKSORT_THRESH=10;
-static const int TQUICKSORT_STACK=512;
+static const int QUICKSORT_STACK=512;
static const int PRESORT_THRESH=10;
static const int PRESORT_DEPTH=8;
static const int RADIX_THRESH=32768;
@@ -283,8 +283,8 @@ void
_BSort::quicksort3r(int lo, int hi, int depth)
{
/* Initialize stack */
- int slo[TQUICKSORT_STACK];
- int shi[TQUICKSORT_STACK];
+ int slo[QUICKSORT_STACK];
+ int shi[QUICKSORT_STACK];
int sp = 1;
slo[0] = lo;
shi[0] = hi;
@@ -342,7 +342,7 @@ _BSort::quicksort3r(int lo, int hi, int depth)
vswap(hi-tmp+1, h+1, tmp, posn);
h1 = hi - (h1-h);
// -- process segments
- ASSERT(sp+2<TQUICKSORT_STACK);
+ ASSERT(sp+2<QUICKSORT_STACK);
// ----- middle segment (=?) [l1, h1]
for(int i=l1;i<=h1;i++)
rank[posn[i]] = h1;
@@ -437,9 +437,9 @@ void
_BSort::quicksort3d(int lo, int hi, int depth)
{
/* Initialize stack */
- int slo[TQUICKSORT_STACK];
- int shi[TQUICKSORT_STACK];
- int sd[TQUICKSORT_STACK];
+ int slo[QUICKSORT_STACK];
+ int shi[QUICKSORT_STACK];
+ int sd[QUICKSORT_STACK];
int sp = 1;
slo[0] = lo;
shi[0] = hi;
@@ -518,7 +518,7 @@ _BSort::quicksort3d(int lo, int hi, int depth)
vswap(hi-tmp+1, h+1, tmp, posn);
h1 = hi - (h1-h);
// -- process segments
- ASSERT(sp+3<TQUICKSORT_STACK);
+ ASSERT(sp+3<QUICKSORT_STACK);
// ----- middle segment (=?) [l1, h1]
l = l1; h = h1;
if (med==0) // special case for marker [slow]
diff --git a/kviewshell/plugins/djvu/libdjvu/JB2EncodeCodec.cpp b/kviewshell/plugins/djvu/libdjvu/JB2EncodeCodec.cpp
index 054d4e09..5a8092a0 100644
--- a/kviewshell/plugins/djvu/libdjvu/JB2EncodeCodec.cpp
+++ b/kviewshell/plugins/djvu/libdjvu/JB2EncodeCodec.cpp
@@ -166,7 +166,7 @@ JB2Image::encode(const GP<ByteStream> &gbs) const
#define MATCHED_REFINE_IMAGE_ONLY (6)
#define MATCHED_COPY (7)
#define NON_MARK_DATA (8)
-#define RETQUIRED_DICT_OR_RESET (9)
+#define REQUIRED_DICT_OR_RESET (9)
#define PRESERVED_COMMENT (10)
#define END_OF_DATA (11)
@@ -364,7 +364,7 @@ JB2Dict::JB2Codec::Encode::code(const GP<JB2Dict> &gjim)
int nshape = jim.get_shape_count();
init_library(jim);
// Code headers.
- int rectype = RETQUIRED_DICT_OR_RESET;
+ int rectype = REQUIRED_DICT_OR_RESET;
if (jim.get_inherited_shape_count() > 0)
code_record(rectype, gjim, 0);
rectype = START_OF_DATA;
@@ -388,7 +388,7 @@ JB2Dict::JB2Codec::Encode::code(const GP<JB2Dict> &gjim)
// Check numcoder status
if (cur_ncell > CELLCHUNK)
{
- rectype = RETQUIRED_DICT_OR_RESET;
+ rectype = REQUIRED_DICT_OR_RESET;
code_record(rectype, 0, 0);
}
}
@@ -440,7 +440,7 @@ JB2Dict::JB2Codec::Encode::code(const GP<JB2Image> &gjim)
}
}
// Code headers.
- int rectype = RETQUIRED_DICT_OR_RESET;
+ int rectype = REQUIRED_DICT_OR_RESET;
if (jim.get_inherited_shape_count() > 0)
code_record(rectype, gjim, 0, 0);
rectype = START_OF_DATA;
@@ -507,7 +507,7 @@ JB2Dict::JB2Codec::Encode::code(const GP<JB2Image> &gjim)
// Check numcoder status
if (cur_ncell > CELLCHUNK)
{
- rectype = RETQUIRED_DICT_OR_RESET;
+ rectype = REQUIRED_DICT_OR_RESET;
code_record(rectype, 0, 0);
}
}
@@ -546,7 +546,7 @@ JB2Dict::JB2Codec::Encode::encode_libonly_shape(
// Check numcoder status
if (cur_ncell > CELLCHUNK)
{
- rectype = RETQUIRED_DICT_OR_RESET;
+ rectype = REQUIRED_DICT_OR_RESET;
code_record(rectype, 0, 0);
}
}
diff --git a/kviewshell/plugins/djvu/libdjvu/JB2Image.cpp b/kviewshell/plugins/djvu/libdjvu/JB2Image.cpp
index bbc06623..7aad9261 100644
--- a/kviewshell/plugins/djvu/libdjvu/JB2Image.cpp
+++ b/kviewshell/plugins/djvu/libdjvu/JB2Image.cpp
@@ -354,7 +354,7 @@ JB2Image::decode(const GP<ByteStream> &gbs, JB2DecoderCallback *cb, void *arg)
#define MATCHED_REFINE_IMAGE_ONLY (6)
#define MATCHED_COPY (7)
#define NON_MARK_DATA (8)
-#define RETQUIRED_DICT_OR_RESET (9)
+#define REQUIRED_DICT_OR_RESET (9)
#define PRESERVED_COMMENT (10)
#define END_OF_DATA (11)
@@ -999,7 +999,7 @@ JB2Dict::JB2Codec::code_record(
code_comment(jim.comment);
break;
}
- case RETQUIRED_DICT_OR_RESET:
+ case REQUIRED_DICT_OR_RESET:
{
if (! gotstartrecordp)
{
@@ -1240,7 +1240,7 @@ JB2Dict::JB2Codec::code_record(
code_comment(jim.comment);
break;
}
- case RETQUIRED_DICT_OR_RESET:
+ case REQUIRED_DICT_OR_RESET:
{
if(!gjim)
{
diff --git a/kviewshell/plugins/djvu/libdjvu/JB2Image.h b/kviewshell/plugins/djvu/libdjvu/JB2Image.h
index 6733e9f5..a8ea8aae 100644
--- a/kviewshell/plugins/djvu/libdjvu/JB2Image.h
+++ b/kviewshell/plugins/djvu/libdjvu/JB2Image.h
@@ -501,7 +501,7 @@ JB2Image::get_blit(int blitno) const
These extensions are described below by reference to the ICFDD
proposal dated August 1999. Both extension make use of the unused
record type value #9# (cf. ICFDD page 24) which has been renamed
- #RETQUIRED_DICT_OR_RESET#.
+ #REQUIRED_DICT_OR_RESET#.
{\bf Shared Shape Dictionaries} --- This extension provides
support for sharing symbol definitions between the pages of a
@@ -515,7 +515,7 @@ JB2Image::get_blit(int blitno) const
by the following records. The first record usually is a ``Start
Of Image'' record describing the size of the image.
- Starting with version 21, a #RETQUIRED_DICT_OR_RESET# (9) record
+ Starting with version 21, a #REQUIRED_DICT_OR_RESET# (9) record
type can appear {\em before} the #START_OF_DATA# (0) record. The
record type field is followed by a single number arithmetically
encoded (cf. ICFDD page 26) using a sixteenth context (cf. ICFDD
@@ -548,7 +548,7 @@ JB2Image::get_blit(int blitno) const
contexts. These contexts are normally allocated when they are used
for the first time (cf. ICFDD informative note, page 27).
- Starting with version 21, a #RETQUIRED_DICT_OR_RESET# (9) record
+ Starting with version 21, a #REQUIRED_DICT_OR_RESET# (9) record
type can appear {\em after} the #START_OF_DATA# (0) record. The
decoder should proceed with the next record after {\em clearing
all binary contexts used for coding numbers}. This operation
@@ -556,7 +556,7 @@ JB2Image::get_blit(int blitno) const
numbers can be deallocated.
Starting with version 21, the JB2 encoder should insert a
#RETQUIRED_DICT_OR_RESET# record type whenever the number of these
allocated binary contexts exceeds #20000#. Only very large
documents ever reach such a large number of allocated binary
contexts (e.g large maps). Hardware implementation however can
@@ -556,7 +556,7 @@ JB2Image::get_blit(int blitno) const
numbers can be deallocated.
Starting with version 21, the JB2 encoder should insert a
- #RETQUIRED_DICT_OR_RESET# record type whenever the number of these
+ #REQUIRED_DICT_OR_RESET# record type whenever the number of these
allocated binary contexts exceeds #20000#. Only very large
documents ever reach such a large number of allocated binary